@@ -1,5 +1,5 @@
 pub mod bst;
-pub mod red_black;
+pub mod rb;
 
 #[derive(Debug)]
 pub struct Node {
@@ -25,9 +25,9 @@ impl Node {
                 } else {
                     node.right = Node::add_new(node.right, value);
                 }
-                return Some(node);
+                Some(node)
             }
-            None => return Some(Node::create(value)),
+            None => Some(Node::create(value)),
         }
     }
 }
